==> basf_logic_components-1.0.6.tar.gz: lib/scanner/validators/barcode_utils.dart <==
import 'dart:ui';

import 'package:basf_logic_components/domain/models/barcode_info.dart';
import 'package:basf_logic_components/l10n/localizations.dart';
import 'package:collection/collection.dart';
import 'package:gs1_barcode_parser/gs1_barcode_parser.dart';

class BarcodeUtils {
  final List<String> _validItemAiList = [
    '241',
    '240',
    '91',
    '92',
    '10',
    '8008',
    '21',
  ];

  bool allBarcodeCharactersAreNumbers(String barcode) {
    return barcode.runes.every((rune) => rune >= 48 && rune <= 57);
  }

  bool isProcessOrder(String barcode) {
    return allBarcodeCharactersAreNumbers(barcode) && barcode.length == 11;
  }

  bool hasFNC1symbols(String barcode) =>
      barcode.contains(String.fromCharCode(29));

  GS1Barcode parseGS1Barcode(String barcode) {
    final String delimiter = String.fromCharCode(29);
    // Split the data into individual AIs using the FNC1 character
    final List<String> elements = barcode.split(delimiter)
      ..removeWhere((element) => element.isEmpty);

    // Create a map to store the parsed AI data
    final Map<String, GS1ParsedElement> aiData = {};

    for (final String element in elements) {
      // The AI code is the first two characters
      final String? aiCode = _validItemAiList.firstWhereOrNull(
        element.startsWith,
      );

      if (aiCode == null) {
        throw FormatException(barcode);
      }

      // The AI value is everything after the first two characters
      final String aiValue = element.substring(aiCode.length);

      // Store the AI code and value in the map
      aiData[aiCode] = GS1ParsedElement(
        aiCode: aiCode,
        rawData: aiValue,
        data: aiValue,
      );
    }

    if (aiData.isEmpty) {
      throw FormatException(barcode);
    }

    return GS1Barcode(
      code: Code(
        type: CodeType.GS1_128,
        codeTitle: 'Product code',
        fnc1: delimiter,
      ),
      elements: aiData,
    );
  }

  String? getSSCCCode(GS1Barcode gs1barcode) {
    final String barcode = gs1barcode.elements.entries.fold(
      '',
      (prevValue, entry) => prevValue += entry.value.rawData,
    );

    if (gs1barcode.AIs.first == '00' &&
        barcode.startsWith('3') &&
        barcode.length == 18 &&
        allBarcodeCharactersAreNumbers(barcode)) {
      return '${gs1barcode.AIs.first}$barcode';
    } else {
      return null;
    }
  }

  String? getUnitItemCode(GS1Barcode gs1barcode) {
    final String barcode = gs1barcode.elements.entries.fold(
      '',
      (prevValue, entry) => prevValue += entry.value.rawData,
    );

    if (gs1barcode.AIs.isNotEmpty &&
        gs1barcode.AIs.every(_validItemAiList.contains) &&
        barcode.isNotEmpty) {
      return barcode;
    } else {
      return null;
    }
  }

  List<BarcodeInfo> getUnitItemBarcodeInfo({
    required GS1Barcode gs1barcode,
    required Locale locale,
  }) {
    return gs1barcode.elements.values
        .map((value) => BarcodeInfo(
              ai: value.aiCode,
              value: value.rawData,
              description: getAiDescription(value.aiCode, locale),
            ))
        .toList();
  }

  String? getAiDescription(String ai, Locale locale) =>
      AppLocalizations.aiDescription(ai, locale);
}

==> basf_logic_components-1.0.8.tar.gz: lib/scanner/validators/barcode_utils.dart <==
import 'dart:ui';

import 'package:basf_logic_components/domain/models/barcode_info.dart';
import 'package:basf_logic_components/l10n/localizations.dart';
import 'package:collection/collection.dart';
import 'package:gs1_barcode_parser/gs1_barcode_parser.dart';

class BarcodeUtils {
  final List<String> _validItemAiList = [
    '241',
    '240',
    '91',
    '92',
    '10',
    '8008',
    '21',
  ];

  bool allBarcodeCharactersAreNumbers(String barcode) {
    return barcode.runes.every((rune) => rune >= 48 && rune <= 57);
  }

  bool isProcessOrder(String barcode) {
    return allBarcodeCharactersAreNumbers(barcode) && barcode.length == 11;
  }

  bool hasFNC1symbols(String barcode) =>
      barcode.contains(String.fromCharCode(29)) || barcode.contains('!');

  GS1Barcode parseGS1Barcode(String barcode) {
    final String delimiter = barcode.contains(String.fromCharCode(29))
        ? String.fromCharCode(29)
        : '!';
    // Split the data into individual AIs using the FNC1 character
    final List<String> elements = barcode.split(delimiter)
      ..removeWhere((element) => element.isEmpty);

    // Create a map to store the parsed AI data
    final Map<String, GS1ParsedElement> aiData = {};

    for (final String element in elements) {
      // The AI code is the first two characters
      final String? aiCode = _validItemAiList.firstWhereOrNull(
        element.startsWith,
      );

      if (aiCode == null) {
        throw FormatException(barcode);
      }

      // The AI value is everything after the first two characters
      final String aiValue = element.substring(aiCode.length);

      // Store the AI code and value in the map
      aiData[aiCode] = GS1ParsedElement(
        aiCode: aiCode,
        rawData: aiValue,
        data: aiValue,
      );
    }

    if (aiData.isEmpty) {
      throw FormatException(barcode);
    }

    return GS1Barcode(
      code: Code(
        type: CodeType.GS1_128,
        codeTitle: 'Product code',
        fnc1: delimiter,
      ),
      elements: aiData,
    );
  }

  String? getSSCCCode(GS1Barcode gs1barcode) {
    final String barcode = gs1barcode.elements.entries.fold(
      '',
      (prevValue, entry) => prevValue += entry.value.rawData,
    );

    if (gs1barcode.AIs.first == '00' &&
        barcode.startsWith('3') &&
        barcode.length == 18 &&
        allBarcodeCharactersAreNumbers(barcode)) {
      return '${gs1barcode.AIs.first}$barcode';
    } else {
      return null;
    }
  }

  String? getUnitItemCode(GS1Barcode gs1barcode) {
    final String barcode = gs1barcode.elements.entries.fold(
      '',
      (prevValue, entry) => prevValue += entry.value.rawData,
    );

    if (gs1barcode.AIs.isNotEmpty &&
        gs1barcode.AIs.every(_validItemAiList.contains) &&
        barcode.isNotEmpty) {
      return barcode;
    } else {
      return null;
    }
  }

  List<BarcodeInfo> getUnitItemBarcodeInfo({
    required GS1Barcode gs1barcode,
    required Locale locale,
  }) {
    return gs1barcode.elements.values
        .map((value) => BarcodeInfo(
              ai: value.aiCode,
              value: value.rawData,
              description: getAiDescription(value.aiCode, locale),
            ))
        .toList();
  }

  String? getAiDescription(String ai, Locale locale) =>
      AppLocalizations.aiDescription(ai, locale);
}
